import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

import 'adgydeflutterplugin_platform_interface.dart';

/// An implementation of [AdgydeflutterpluginPlatform] that uses method channels.
class MethodChannelAdgydeflutterplugin extends AdgydeflutterpluginPlatform {
  /// The method channel used to interact with the native platform.
  String deeplink = "";
  String userId = "";
  String campaignName = "";
  int campaignId = 0;

  String channelName = "";
  int channelId = 0;

  String mediaSource = "";
  String utmSource = "";

  @visibleForTesting
  final instance = const MethodChannel('adgydeplugin');

  @override
  Future<String?> getPlatformVersion() async {
    final version = await instance.invokeMethod<String>('getPlatformVersion');
    return version;
  }

  void init(String appkey, String channel) {
    instance.invokeMethod(
        "init", <String, dynamic>{'appkey': appkey, 'channel': channel});
  }

  void simpleEvent(String eventValue) {
    instance.invokeMethod("simpleEvent", eventValue);
  }

  void countingEvent(String eventId, Map eventValue) {
    instance.invokeMethod("countingEvent",
        <String, dynamic>{'eventId': eventId, 'eventValue': eventValue});
  }

  void computingEvent(String eventId, Map eventValue) {
    instance.invokeMethod("computingEvent",
        <String, dynamic>{'eventId': eventId, 'eventValue': eventValue});
  }

  void daliyUnique(String eventId, Map eventValue) {
    instance.invokeMethod("daliyUnique",
        <String, dynamic>{'eventId': eventId, 'eventValue': eventValue});
  }

  void permanentUnique(String eventId, Map eventValue) {
    instance.invokeMethod("permanentUnique",
        <String, dynamic>{'eventId': eventId, 'eventValue': eventValue});
  }

  void customUnique(String eventId, Map eventValue, int time) {
    instance.invokeMethod("customUnique", <String, dynamic>{
      'eventId': eventId,
      'eventValue': eventValue,
      'time': time
    });
  }

  void setCurrentScreen(String screenName) {
    instance.invokeMethod("setCurrentScreen", screenName);
  }

  void removeCurrentScreen(String screenName) {
    instance.invokeMethod("removeCurrentScreen", screenName);
  }

  void getEmailId(String emailId) {
    instance.invokeMethod("getEmailId", emailId);
  }

  void getPhoneNumber(int phoneno) {
    instance.invokeMethod("getPhoneNumber", phoneno);
  }

  void setClientUserId(String clientUserid) {
    instance.invokeMethod("setClientUserId", clientUserid);
  }

  void revenueEvent(int revenue) {
    instance.invokeMethod("revenueEvent", revenue);
  }

  void fcmToken(String token) {
    instance.invokeMethod("fcmToken", token);
  }

  void setAge(String age) {
    instance.invokeMethod("setAge", age);
  }

  void setGender(String gender) {
    instance.invokeMethod("setGender", gender);
  }

  void setImeiPermission(bool imei) {
    instance.invokeMethod("setIMEIPermission", imei);
  }

  Future<String?> getDeeplinkData() async {
    dynamic result;
    try {
      result = await instance.invokeMethod('getDeeplinking');
      deeplink = result;
    } on PlatformException catch (e) {
      deeplink = "Failed to Invoke: '${e.message}'.";
    }
    return result;
  }

  Future<String?> getUserId() async {
    dynamic result;
    try {
      result = await instance.invokeMethod('getUserId');
      userId = result;
    } on PlatformException catch (e) {
      userId = "Failed to Invoke: getUserId '${e.message}'.";
    }
    return result;
  }

  Future<String?> getCampaignName() async {
    dynamic result;
    try {
      result = await instance.invokeMethod('getCampaignName');
      campaignName = result;
    } on PlatformException catch (e) {
      campaignName = "Failed to Invoke: getCampaignName'${e.message}'.";
    }
    return result;
  }

  Future<String?> getCampaignId() async {
    dynamic result;
    try {
      result = await instance.invokeMethod('getCampaignId');
      campaignId = result;
    } on PlatformException catch (e) {
      //campaignId = "Failed to Invoke: getCampaignId'${e.message}'.";
    }
    return result;
  }

  Future<String?> getChannelName() async {
    dynamic result;
    try {
      result = await instance.invokeMethod('getChannelName');
      channelName = result;
    } on PlatformException catch (e) {
      channelName = "Failed to Invoke: getChannelName'${e.message}'.";
    }
    return result;
  }

  Future<String?> getchannelId() async {
    dynamic  result;
    try {
      result = await instance.invokeMethod('getChannelId');
      channelId = result;
    } on PlatformException catch (e) {
      e.message;
    }
    return result;
  }

  Future<String?> getMediaSource() async {
    dynamic  result;
    try {
      final String result = await instance.invokeMethod('getMediaSource');
      mediaSource = result;
    } on PlatformException catch (e) {
      mediaSource = "Failed to Invoke: getMediaSource'${e.message}'.";
    }
    return result;
  }

  Future<String?> getUtmSource() async {
    dynamic  result;
    try {
      result = await instance.invokeMethod('getUtmSource');
      utmSource = result;
    } on PlatformException catch (e) {
      utmSource = "Failed to Invoke: getUtmSource'${e.message}'.";
    }
    return result;
  }

}
